@@ -1,6 +1,6 @@
 /* apt-dater - terminal-based remote package update manager
  *
- * $Id: keyfiles.c 358 2009-05-25 11:39:38Z liske $
+ * $Id: keyfiles.c 484 2010-02-21 15:37:06Z liske $
  *
  * Authors:
  *   Andre Ellguth <ellguth@ibh.de>
@@ -40,10 +40,10 @@ static char apt_dater_conf[] = "# Config file of apt-dater in the form of the"
  " glib GKeyFile required\n\n[Paths]\n# Default: $XDG_CONFIG_HOME/apt-dater/h"
  "osts.conf\n#HostsFile=path-to/hosts.conf\n\n# Default: $XDG_DATA_HOME/apt-d"
  "ater\n#StatsDir=path-to/stats\n\n[SSH]\n# SSH binary\nCmd=/usr/bin/ssh\nOpt"
- "ionalCmdFlags=-t\n\n# SFTP binary\nSFTPCmd=/usr/bin/mc /#sh:%u@%h:C/\n\nDefau"
- "ltUser=apt-dater\nDefaultPort=22\n\n#[Screen]\n## Default: $XDG_CONFIG_HOME"
+ "ionalCmdFlags=-t\n\n# SFTP binary\nSFTPCmd=/usr/bin/sftp\n\n"
+ "#[Screen]\n## Default: $XDG_CONFIG_HOME"
  "/apt-dater/screenrc\n#RCFile=path-to/screenrc\n#\n## Default: %m # %u@%h:%p"
- "\n#Title=%m # %u@%h:%p\n#\n\n# These values requires apt-dater-host to be i"
+ "\n#Title=%m # %U%H\n#\n\n# These values requires apt-dater-host to be i"
  "nstalled on the target host.\n# You could call apt/aptitude directly (see a"
  "pt-dater-host source),\n# but this is not recommended.\n[Commands]\nCmdRefr"
  "esh=apt-dater-host refresh\nCmdUpgrade=apt-dater-host upgrade\nCmdInstall=a"
@@ -107,29 +107,29 @@ int chkForInitialConfig(const gchar *cfgdir, const gchar *cfgfile)
    if(!pathtofile) g_error(_("Out of memory."));
    fp = fopen(pathtofile, "wx");
    g_message(_("Creating file %s"), pathtofile);
-   g_free(pathtofile);
    if(fp) {
-    fwrite(hosts_conf, sizeof(hosts_conf)-1, 1, fp);
+    if(fwrite(hosts_conf, sizeof(hosts_conf)-1, 1, fp) != 1) g_error(_("Could not write to file %s."), pathtofile);
     fclose(fp);
    }
+   g_free(pathtofile);
 
    /* Create a the example screenrc */
    pathtofile = g_strdup_printf("%s/screenrc", cfgdir);
    if(!pathtofile) g_error(_("Out of memory."));
    fp = fopen(pathtofile, "wx");
    g_message(_("Creating file %s"), pathtofile);
-   g_free(pathtofile);
    if(fp) {
-    fwrite(screenrc, sizeof(screenrc)-1, 1, fp);
+    if(fwrite(screenrc, sizeof(screenrc)-1, 1, fp) != 1) g_error(_("Could not write to file %s."), pathtofile);
     fclose(fp);
    }
+   g_free(pathtofile);
 
    /* Create initial config file */
    fp = fopen(cfgfile, "wx");
    if(!fp) return(1);
 
    g_message(_("Creating file %s"), cfgfile);
-   fwrite(apt_dater_conf, sizeof(apt_dater_conf)-1, 1, fp);
+   if(fwrite(apt_dater_conf, sizeof(apt_dater_conf)-1, 1, fp) != 1) g_error(_("Could not write to file %s."), cfgfile);
    fclose(fp);
   }
  }
@@ -148,7 +148,6 @@ void freeConfig (CfgFile *cfg)
  g_free(cfg->statsdir);
  g_free(cfg->ssh_cmd);
  g_free(cfg->ssh_optflags);
- g_free(cfg->ssh_defuser);
  g_free(cfg->sftp_cmd);
  g_free(cfg->cmd_refresh);
  g_free(cfg->cmd_upgrade);
@@ -198,7 +197,7 @@ CfgFile *loadConfig (char *filename)
     lcfg->screenrcfile = g_strdup_printf("%s/%s/%s", g_get_user_config_dir(), PROG_NAME, "screenrc");
  if(!(lcfg->screentitle = 
       g_key_file_get_string(keyfile, "Screen", "Title", NULL)))
-    lcfg->screentitle = g_strdup("%m # %u@%h:%p");
+    lcfg->screentitle = g_strdup("%m # %U%H");
 
  if(!(lcfg->ssh_cmd = 
       g_key_file_get_string(keyfile, "SSH", "Cmd", &error))) {
@@ -206,18 +205,6 @@ CfgFile *loadConfig (char *filename)
   return (NULL);
  }
 
- if(!(lcfg->ssh_defuser = 
-      g_key_file_get_string(keyfile, "SSH", "DefaultUser", &error))) {
-  g_error ("%s: %s", filename, error->message);
-  return (NULL);
- }
-
- if(!(lcfg->ssh_defport = 
-      g_key_file_get_integer(keyfile, "SSH", "DefaultPort", &error))) {
-  g_error ("%s: %s", filename, error->message);
-  return (NULL);
- }
-
  if(!(lcfg->sftp_cmd = 
       g_key_file_get_string(keyfile, "SSH", "SFTPCmd", &error))) {
   g_error ("%s: %s", filename, error->message);
@@ -300,16 +287,29 @@ CfgFile *loadConfig (char *filename)
    lcfg->record_history = TRUE;
    g_clear_error(&error);
  }
- if(lcfg->record_history && (g_access(PKGLIBDIR"/script", X_OK) != 0)) {
-   g_warning("Executable "PKGLIBDIR"/script not available, disabling history feature.");
-   lcfg->record_history = FALSE;
- }
 
  lcfg->history_errpattern = g_key_file_get_string(keyfile, "History", "ErrPattern", NULL);
  if(!lcfg->history_errpattern)
   lcfg->history_errpattern = "(error|warning|fail)";
 #endif
 
+#define KEY_FILE_GET_STRING_DEFAULT(var, sec, val, default) \
+ (var) = g_key_file_get_string(keyfile, sec, val, NULL); \
+ if(!(var)) \
+  (var) = (default);
+
+ KEY_FILE_GET_STRING_DEFAULT(lcfg->hook_pre_upgrade, "Hooks", "PreUpgrade" , "/etc/apt-dater/pre-upg.d");
+ KEY_FILE_GET_STRING_DEFAULT(lcfg->hook_pre_refresh, "Hooks", "PreRefresh", "/etc/apt-dater/pre-ref.d");
+ KEY_FILE_GET_STRING_DEFAULT(lcfg->hook_pre_install, "Hooks", "PreInstall", "/etc/apt-dater/pre-ins.d");
+ KEY_FILE_GET_STRING_DEFAULT(lcfg->hook_pre_connect, "Hooks", "PreConnect", "/etc/apt-dater/pre-con.d");
+
+ KEY_FILE_GET_STRING_DEFAULT(lcfg->hook_post_upgrade, "Hooks", "PostUpgrade" , "/etc/apt-dater/post-upg.d");
+ KEY_FILE_GET_STRING_DEFAULT(lcfg->hook_post_refresh, "Hooks", "PostRefresh", "/etc/apt-dater/post-ref.d");
+ KEY_FILE_GET_STRING_DEFAULT(lcfg->hook_post_install, "Hooks", "PostInstall", "/etc/apt-dater/post-ins.d");
+ KEY_FILE_GET_STRING_DEFAULT(lcfg->hook_post_connect, "Hooks", "PostConnect", "/etc/apt-dater/post-con.d");
+
+ KEY_FILE_GET_STRING_DEFAULT(lcfg->plugindir, "Hooks", "PluginDir", "/etc/apt-dater/plugins");
+
  g_clear_error(&error);
  g_key_file_free(keyfile);
 
@@ -340,7 +340,7 @@ GList *loadHosts (char *filename)
   g_key_file_free(keyfile);
   return (FALSE);
  }
- 
+
  groups = g_key_file_get_groups (keyfile, &lengrp);
  qsort(groups, lengrp, sizeof(gchar *), cmpStringP);
 
@@ -354,6 +354,10 @@ GList *loadHosts (char *filename)
 
   qsort(khosts, lenkey, sizeof(gchar *), cmpStringP);
 
+  gchar *host_type = g_key_file_get_string(keyfile, groups[i], "Type", NULL);
+  if(!host_type)
+   host_type = "generic-ssh";
+
   for(j = 0; j < lenkey; j++) {
    hostnode = g_new0(HostNode, 1);
 #ifndef NDEBUG
@@ -374,16 +378,22 @@ GList *loadHosts (char *filename)
    }
 
    hostnode->hostname = g_strdup(hostname);
-   hostnode->ssh_user = *ssh_user ? g_strdup(ssh_user) : g_strdup(cfg->ssh_defuser);
-   hostnode->ssh_port = ssh_port ? ssh_port : cfg->ssh_defport;
+   hostnode->ssh_user = *ssh_user ? g_strdup(ssh_user) : NULL;
+   hostnode->ssh_port = ssh_port ? ssh_port : 0;
+
+   hostnode->statsfile = g_strdup_printf("%s/%s:%d.stat", cfg->statsdir, hostnode->hostname, hostnode->ssh_port);
 
    hostnode->fdlock = -1;
-   hostnode->identity_file = g_key_file_get_string(keyfile, groups[i], 
+   hostnode->identity_file = g_key_file_get_string(keyfile, groups[i],
 						  "IdentityFile", &error);
    hostnode->tagged = FALSE;
    g_clear_error(&error);
 
-   hostnode->group = g_strdup(groups[i]);
+   hostnode->group = groups[i];
+   hostnode->type = host_type;
+
+   hostnode->uuid[0] = 0;
+
    getUpdatesFromStat(hostnode);
 
    hosts = g_list_append(hosts, hostnode);
@@ -392,7 +402,6 @@ GList *loadHosts (char *filename)
   }
 
   g_free(khosts);
-  g_free(groups[i]);
  }
 
  g_free(groups);
