@@ -1,6 +1,6 @@
 /* apt-dater - terminal-based remote package update manager
  *
- * $Id: lock.c 324 2009-04-27 10:45:19Z liske $
+ * $Id: lock.c 507 2010-03-22 11:46:46Z liske $
  *
  * Authors:
  *   Andre Ellguth <ellguth@ibh.de>
@@ -40,12 +40,8 @@ static GList *lockList = NULL;
 static gchar *getLockFile(const HostNode *n)
 {
  gchar *lockfile = NULL;
- gchar *statsfile = NULL;
 
- statsfile = getStatsFileName(n);
-
- lockfile = g_strdup_printf("%s.lck", statsfile);
- g_free(statsfile);
+ lockfile = g_strdup_printf("%s.lck", n->statsfile);
 
  return(lockfile);
 }
@@ -111,11 +107,13 @@ int unsetLockForHost(HostNode *n)
 #ifdef HAVE_FLOCK
  r = flock(n->fdlock, LOCK_UN);
  lockList = g_list_remove(lockList, n);
+#else
+ r = EXIT_SUCCESS;
 #endif
 
  close(n->fdlock);
  n->fdlock = -1;
-  
+
  return(r);
 }
 
