@@ -1,13 +1,13 @@
 /* apt-dater - terminal-based remote package update manager
  *
- * $Id: report.c 310 2009-03-06 18:31:03Z liske $
+ * $Id: report.c 457 2010-01-30 13:20:35Z liske $
  *
  * Authors:
  *   Andre Ellguth <ellguth@ibh.de>
  *   Thomas Liske <liske@ibh.de>
  *
  * Copyright Holder:
- *   2008 (C) IBH IT-Service GmbH [http://www.ibh.de/apt-dater/]
+ *   2008-2009 (C) IBH IT-Service GmbH [http://www.ibh.de/apt-dater/]
  *
  * License:
  *   This program is free software; you can redistribute it and/or modify
@@ -41,6 +41,10 @@
 static xmlTextWriterPtr writer;
 static xmlDocPtr doc;
 
+#ifdef FEAT_HISTORY
+#include "history.h"
+#endif
+
 void initReport(GList *hosts) {
   /*
    * this initialize the library and check potential ABI mismatches
@@ -49,13 +53,15 @@ void initReport(GList *hosts) {
    */
   LIBXML_TEST_VERSION
 
-  fprintf(stderr, _("apt-dater is refreshing %d hosts, please standby...\n"), g_list_length(hosts));
-
   writer = xmlNewTextWriterDoc(&doc, 0);
   if (writer == NULL)
     g_error(_("Error creating the xml output."));
   xmlTextWriterStartDocument(writer, NULL, NULL, NULL);
 
+  if(!hosts) return;
+
+  fprintf(stderr, _("apt-dater is refreshing %d hosts, please standby...\n"), g_list_length(hosts));
+
   GList *n = hosts;
   while(n) {
     ((HostNode *)n->data)->category = C_REFRESH_REQUIRED;
@@ -64,6 +70,29 @@ void initReport(GList *hosts) {
   }
 }
 
+#ifdef FEAT_HISTORY
+static void reportHistory(gpointer data, gpointer user_data) {
+  HistoryEntry *h = (HistoryEntry *)data;
+
+  xmlTextWriterStartElement(writer, BAD_CAST(h->action));
+
+  xmlTextWriterWriteFormatElement(writer, BAD_CAST("timestamp"), "%d", (int)h->ts);
+  xmlTextWriterWriteFormatElement(writer, BAD_CAST("duration"), "%d", h->duration);
+
+  xmlTextWriterStartElement(writer, BAD_CAST("path"));
+  xmlTextWriterWriteString(writer, BAD_CAST(h->path));
+  xmlTextWriterEndElement(writer);
+
+  if(h->maintainer && strlen(h->maintainer)) {
+    xmlTextWriterStartElement(writer, BAD_CAST("maintainer"));
+    xmlTextWriterWriteString(writer, BAD_CAST(h->maintainer));
+    xmlTextWriterEndElement(writer);
+  }
+
+  xmlTextWriterEndElement(writer);
+}
+#endif
+
 static void reportPackage(gpointer data, gpointer user_data) {
   PkgNode *n = (PkgNode *)data;
   
@@ -119,8 +148,10 @@ static void reportHost(gpointer data, gpointer lgroup) {
 
   /* SSH config */
   xmlTextWriterStartElement(writer, BAD_CAST("ssh"));
-  xmlTextWriterWriteElement(writer, BAD_CAST("user"), BAD_CAST(n->ssh_user));
-  xmlTextWriterWriteFormatElement(writer, BAD_CAST("port"), "%d", n->ssh_port);
+  if(n->ssh_user)
+    xmlTextWriterWriteElement(writer, BAD_CAST("user"), BAD_CAST(n->ssh_user));
+  if(n->ssh_port)
+    xmlTextWriterWriteFormatElement(writer, BAD_CAST("port"), "%d", n->ssh_port);
   xmlTextWriterEndElement(writer);
 
   /* Kernel info */
@@ -157,6 +188,18 @@ static void reportHost(gpointer data, gpointer lgroup) {
   else
     xmlTextWriterWriteElement(writer, BAD_CAST("virt"), BAD_CAST("Unknown"));
 
+#ifdef FEAT_HISTORY
+  /* history data */
+  GList *hel = history_get_entries(n);
+  if(hel) {
+    xmlTextWriterStartElement(writer, BAD_CAST("history"));
+    g_list_foreach(hel, reportHistory, NULL);
+    xmlTextWriterEndElement(writer);
+
+    history_free_hel(hel);
+  }
+#endif
+
   /* Packages */
   xmlTextWriterStartElement(writer, BAD_CAST("packages"));
   g_list_foreach(n->packages, reportPackage, NULL);
@@ -183,7 +226,7 @@ gboolean ctrlReport(GList *hosts) {
   if(torefresh == 0) {
     /* Create root node. */
     xmlTextWriterStartElement(writer, BAD_CAST("report"));
-    xmlTextWriterWriteFormatElement(writer, BAD_CAST("timestamp"), "%d", time(NULL));
+    xmlTextWriterWriteFormatElement(writer, BAD_CAST("timestamp"), "%d", (int)time(NULL));
 
     /* Put node stats to file. */
     g_list_foreach(hosts, reportHost, &lgroup);
