@@ -1,6 +1,6 @@
 /* apt-dater - terminal-based remote package update manager
  *
- * $Id: screen.c 358 2009-05-25 11:39:38Z liske $
+ * $Id: screen.c 484 2010-02-21 15:37:06Z liske $
  *
  * Authors:
  *   Andre Ellguth <ellguth@ibh.de>
@@ -51,7 +51,7 @@ screen_get_sdir() {
   if (!pw)
     return NULL;
 
-  g_snprintf(sdir, sizeof(sdir), SCREEN_SDFORMT, SCREEN_SOCKDIR, pw->pw_name);
+  g_snprintf(sdir, sizeof(sdir), SCREEN_SDFORMT, SCREEN_SOCKPATH, pw->pw_name);
 
   return sdir;
 }
@@ -107,48 +107,14 @@ screen_get_sessions(HostNode *n) {
 }
 
 gchar *
-screen_new(HostNode *n, const gboolean detached, const HistoryEntry *he) {
-  if (!cfg->use_screen) {
-#ifdef FEAT_HISTORY
-    if(cfg->record_history && he) {
-     gchar *hp = history_rec_path(n);
-     gchar *fn_meta = g_strdup_printf("%s/meta", hp);
-     history_write_meta(fn_meta, he);
-     g_free(fn_meta);
+screen_new(HostNode *n, const gboolean detached) {
 
-     gchar *cmd = g_strdup_printf(PKGLIBDIR"/script+%s+%s+", hp, cfg->history_errpattern);
-     g_free(hp);
-
-     return cmd;
-    }
-    else
-#endif
+  if (!cfg->use_screen)
      return g_strdup("");
-  }
 
   gchar *title = parse_string(cfg->screentitle, n);
 
-  gchar *cmd;
-
-#ifdef FEAT_HISTORY
-  if(cfg->record_history && he) {
-    gchar *hp = history_rec_path(n);
-    gchar *fn_meta = g_strdup_printf("%s/meta", hp);
-    history_write_meta(fn_meta, he);
-    g_free(fn_meta);
-
-    cmd = g_strdup_printf(SCREEN_BINARY"+-%sS+"SCREEN_SOCKPRE"%s_%s_%d"	\
-			       "+-t+%s+-c+%s+"PKGLIBDIR"/script+%s+%s+",
-			       detached ? "dm" : "",
-			       n->ssh_user, n->hostname, n->ssh_port,
-			       title,
-			       cfg->screenrcfile,
-			       hp, cfg->history_errpattern);
-
-    g_free(hp);
-  } else
-#endif
-    cmd = g_strdup_printf(SCREEN_BINARY"+-%sS+"SCREEN_SOCKPRE"%s_%s_%d"	\
+  gchar *cmd = g_strdup_printf(SCREEN_BINARY"+-%sS+"SCREEN_SOCKPRE"%s_%s_%d"	\
 			       "+-t+%s+-c+%s+",
 			       detached ? "dm" : "",
 			       n->ssh_user, n->hostname, n->ssh_port,
