@@ -1,6 +1,6 @@
 /* apt-dater - terminal-based remote package update manager
  *
- * $Id: ui.c 367 2009-05-26 12:49:12Z ellguth $
+ * $Id: ui.c 511 2010-03-25 16:40:06Z liske $
  *
  * Authors:
  *   Andre Ellguth <ellguth@ibh.de>
@@ -178,24 +178,25 @@ static struct ShortCut shortCuts[] = {
 #ifdef FEAT_HISTORY
  {SC_KEY_HISTORY, 'H', "H", N_("host history") , FALSE, 0},
  {SC_KEY_PLAY, 'p', "p" , N_("play") , FALSE, VK_PLAY},
- {SC_KEY_LESS, 'l', "l" , N_("display with less") , FALSE, VK_LESS},
+ {SC_KEY_LESS, 'L', "L" , N_("display with less") , FALSE, VK_LESS},
 #endif
  {SC_KEY_NEXTSESS, 'n', "n" , N_("next detached session") , FALSE, 0},
  {SC_KEY_CYCLESESS, 'N', "N" , N_("cycle detached sessions") , FALSE, 0},
  {SC_KEY_TAG, 't', "t" , N_("tag current host") , FALSE, 0},
  {SC_KEY_TAGMATCH, 'T', "T" , N_("tag all hosts matching") , FALSE, 0},
+ {SC_KEY_UNUSED, KEY_MAX, "" , N_(" ~c tag by codename") , FALSE, 0},
+ {SC_KEY_UNUSED, KEY_MAX, "" , N_(" ~d tag by distribution") , FALSE, 0},
+ {SC_KEY_UNUSED, KEY_MAX, "" , N_(" ~f tag by host flags") , FALSE, 0},
+ {SC_KEY_UNUSED, KEY_MAX, "" , N_(" ~g tag by group") , FALSE, 0},
+ {SC_KEY_UNUSED, KEY_MAX, "" , N_(" ~p tag by packages") , FALSE, 0},
+ {SC_KEY_UNUSED, KEY_MAX, "" , N_(" ~u tag by updates") , FALSE, 0},
+ {SC_KEY_UNUSED, KEY_MAX, "" , N_(" ~A tag all hosts") , FALSE, 0},
  {SC_KEY_UNTAGMATCH, ctrl('T'), "^T" , N_("untag all hosts matching") , FALSE, 0},
  {SC_KEY_TAGACTION, ';', ";" , N_("apply next function to tagged hosts") , FALSE, 0},
  {SC_MAX, 0, NULL, NULL, FALSE, 0},
 };
 
-struct HostFlag {
-  gint flag;
-  gchar *code;
-  gchar *descr;
-};
-
-static const struct HostFlag hostFlags[] = {
+const struct HostFlag hostFlags[] = {
   {HOST_STATUS_PKGKEPTBACK    ,  "h", N_("some packages are kept back")},
   {HOST_STATUS_PKGEXTRA       ,  "x", N_("extra packages are installed")},
   {HOST_STATUS_KERNELNOTMATCH ,  "R", N_("running kernel is not the latest (reboot required)")},
@@ -554,8 +555,8 @@ void drawMenu (gint mask)
    addnstr(":", MAX(0, p));
    p--;
 
-   addnstr(shortCuts[i].descr, MAX(0, p));
-   p -= strlen(shortCuts[i].descr);
+   addnstr(_(shortCuts[i].descr), MAX(0, p));
+   p -= strlen(_(shortCuts[i].descr));
 
    addnstr("  ", MAX(0, p));
    p-=2;
@@ -658,10 +659,10 @@ gboolean queryConfirm(const gchar *query, const gboolean enter_is_yes, gboolean
  remln(COLS);
 
  if (has_canceled) {
-    *has_canceled = ((c == 'c') || (c == 'C') || (c == 27));
+    *has_canceled = ((c == _("c")[0]) || (c == _("C")[0]) || (c == 27));
  }
 
- return ((c == 'y') || (c == 'Y') || 
+ return ((c == _("y")[0]) || (c == _("Y")[0]) || 
 	 (enter_is_yes == TRUE && (c == 0xd || c == KEY_ENTER)));
 }
 
@@ -877,15 +878,15 @@ void drawCategoryEntry (DrawNode *n)
  else
   addch(' ');
 
- addnstr((char *) n->p, COLS);
+ addnstr(_((char *) n->p), COLS);
  attroff(n->attrs);
 
  if(n->selected == TRUE) {
   if (n->elements > 1 || n->elements == 0) {
-   snprintf(statusln, BUF_MAX_LEN, _("%d Hosts in status \"%s\""), n->elements, (char *) n->p);
+   snprintf(statusln, BUF_MAX_LEN, _("%d Hosts in status \"%s\""), n->elements, _((char *) n->p));
   }
   else {
-   snprintf(statusln, BUF_MAX_LEN, _("%d Host in status \"%s\""), n->elements, (char *) n->p);
+   snprintf(statusln, BUF_MAX_LEN, _("%d Host in status \"%s\""), n->elements, _((char *) n->p));
   }
 
   drawMenu(VK_REFRESH);
@@ -913,10 +914,10 @@ void drawGroupEntry (DrawNode *n)
 
  if(n->selected == TRUE) {
   if (n->elements > 1 || n->elements == 0) {
-   snprintf(statusln, BUF_MAX_LEN, _("%d Hosts in status \"%s\""), n->elements, incategory);
+   snprintf(statusln, BUF_MAX_LEN, _("%d Hosts in status \"%s\""), n->elements, _(incategory));
   }
   else {
-   snprintf(statusln, BUF_MAX_LEN, _("%d Host in status \"%s\""), n->elements, incategory);
+   snprintf(statusln, BUF_MAX_LEN, _("%d Host in status \"%s\""), n->elements, _(incategory));
   }
 
   drawMenu(VK_REFRESH);
@@ -972,7 +973,7 @@ void drawHostEntry (DrawNode *n)
     attron(A_UNDERLINE);
 
  if(((HostNode *) n->p)->lsb_distributor) {
-  if(((HostNode *) n->p)->ssh_port == 22)
+  if(!HOST_SSHPORT_SET((HostNode *) n->p))
    hostentry = g_strdup_printf("%s (%s %s %s; %s)", 
 			      ((HostNode *) n->p)->hostname,
 			      ((HostNode *) n->p)->lsb_distributor, 
@@ -991,7 +992,7 @@ void drawHostEntry (DrawNode *n)
   addnstr((char *) hostentry, COLS - 11);
   g_free(hostentry);
  } else {
-  if(((HostNode *) n->p)->ssh_port == cfg->ssh_defport)
+  if(!HOST_SSHPORT_SET((HostNode *) n->p))
    addnstr((char *) ((HostNode *) n->p)->hostname, COLS - 11);
   else {
    hostentry = g_strdup_printf("%s:%d",
@@ -1132,6 +1133,7 @@ void drawSessionEntry (DrawNode *n)
 {
  char h[BUF_MAX_LEN];
  struct tm *tm_mtime;
+ char statusln[BUF_MAX_LEN];
 
  snprintf(h, sizeof(h), "%5d: ", ((SessNode *) n->p)->pid);
 
@@ -1152,6 +1154,10 @@ void drawSessionEntry (DrawNode *n)
   if (dump_screen) {
    if(refreshDumpWindow (n) == FALSE)
     drawQuery(_("Could not read session dump."), G_USEC_PER_SEC);
+  } else {
+   snprintf(statusln, sizeof(statusln), "Session is %s",
+	    (screen_is_attached((SessNode *) n->p) ? _("attached") : _("detached")));
+   drawStatus(statusln, TRUE);
   }
  }
 }
@@ -1247,7 +1253,8 @@ void drawEntry (DrawNode *n)
 
 void refreshDraw()
 {
- clear();
+ /* clear(); Don't clear stupid the hole screen. */
+ cleanBetween();
  detectPos();
 
  if(dump_screen) {
@@ -2379,7 +2386,7 @@ void applyFilter(GList *hosts) {
 	case TCLM_IGNORE:
 	  break;
 	default:
-	  g_warning(_("Internal error: unkown TCL mapping type!"));
+	  g_warning(_("Internal error: unknown TCL mapping type!"));
       }
     }
 
@@ -2522,7 +2529,12 @@ static void handleErrors(HostNode *n) {
  if(!he)
   return;
 
- gchar *query = g_strdup_printf(_("An error at %s:%d has been detected [Lic]: "), n->hostname, n->ssh_port);
+ gchar *query;
+
+ if(HOST_SSHPORT_SET(n))
+  query = g_strdup_printf(_("An error at %s:%d has been detected [Less/ignore/connect]: "), n->hostname, n->ssh_port);
+ else
+  query = g_strdup_printf(_("An error at %s has been detected [Less/ignore/connect]: "), n->hostname);
 
  notifyUser();
  while(1) {
@@ -2612,6 +2624,7 @@ gboolean ctrlUI (GList *hosts)
   refscr = TRUE;
   dump_screen = FALSE;
   bottomDrawLine = LINES-2;
+  clear();
  }
 #endif
 
@@ -2805,8 +2818,16 @@ gboolean ctrlUI (GList *hosts)
 
      while(ho) {
       HostNode *m = (HostNode *)ho->data;
-      if((n->type == GROUP && (strcmp(m->group, ingroup) == 0) && m->category == cat) ||
+#ifdef FEAT_TCLFILTER
+      if((n->type == GROUP && (strcmp(m->group, ingroup) == 0) && 
+	  ((cat == C_FILTERED && m->filtered == TRUE) || m->category == cat)) ||
+	 (n->type == CATEGORY && 
+	  ((cat == C_FILTERED && m->filtered == TRUE) || m->category == cat))) {
+#else
+      if((n->type == GROUP && (strcmp(m->group, ingroup) == 0) && 
+	  m->category == cat) ||
 	 (n->type == CATEGORY && m->category == cat)) {
+#endif
        if(m->forbid ^ HOST_FORBID_UPGRADE)
         ssh_cmd_upgrade(m, TRUE);
       }
@@ -2927,8 +2948,16 @@ gboolean ctrlUI (GList *hosts)
 
      while(ho) {
       HostNode *m = (HostNode *)ho->data;
-      if((n->type == GROUP && (strcmp(m->group, ingroup) == 0) && m->category == cat) ||
+#ifdef FEAT_TCLFILTER
+      if((n->type == GROUP && (strcmp(m->group, ingroup) == 0) && 
+	  ((cat == C_FILTERED && m->filtered == TRUE) || m->category == cat)) ||
+	 (n->type == CATEGORY && 
+	  ((cat == C_FILTERED && m->filtered == TRUE) || m->category == cat))) {
+#else
+      if((n->type == GROUP && (strcmp(m->group, ingroup) == 0) && 
+	  m->category == cat) ||
 	 (n->type == CATEGORY && m->category == cat)) {
+#endif
 
        if(m->forbid ^ HOST_FORBID_INSTALL)
         ssh_cmd_install(m, in, TRUE);
@@ -3187,7 +3216,7 @@ gboolean ctrlUI (GList *hosts)
     gint i = -1;
     while(hostFlags[++i].flag) {
      mvwaddch  (wp, l,  2, hostFlags[i].code[0]);
-     mvwaddnstr(wp, l, 16, hostFlags[i].descr, COLS - 16);
+     mvwaddnstr(wp, l, 16, _(hostFlags[i].descr), COLS - 16);
      l++;
     }
     l++;
@@ -3199,8 +3228,8 @@ gboolean ctrlUI (GList *hosts)
 
     i = -1;
     while(shortCuts[++i].key) {
-     mvwaddnstr(wp, l,  2, shortCuts[i].key  , COLS - 2);
-     mvwaddnstr(wp, l, 16, shortCuts[i].descr, COLS - 16);
+     mvwaddnstr(wp, l,  2, _(shortCuts[i].key)  , COLS - 2);
+     mvwaddnstr(wp, l, 16, _(shortCuts[i].descr), COLS - 16);
        
      l++;
     }
@@ -3249,41 +3278,45 @@ gboolean ctrlUI (GList *hosts)
     keypad(wp, TRUE);
 
     wattron(wp, A_BOLD);
-    mvwaddnstr(wp, l++,  1, _("HOST DETAILS")  , COLS - 1);
+    mvwaddnstr(wp, l++,  1, _("HOST DETAILS"), COLS - 1);
     wattroff(wp, A_BOLD);
 
-    mvwaddnstr(wp, l  ,  2, _("Group:")               , COLS -  2);
-    mvwaddnstr(wp, l++, 20, inhost->group          , COLS - 20);
-    mvwaddnstr(wp, l  ,  2, _("Hostname:")            , COLS -  2);
-    mvwaddnstr(wp, l++, 20, inhost->hostname       , COLS - 20);
+    mvwaddnstr(wp, l  ,  2, _("Group:"), COLS -  2);
+    mvwaddnstr(wp, l++, 20, inhost->group, COLS - 20);
+    mvwaddnstr(wp, l  ,  2, _("Hostname:"), COLS -  2);
+    mvwaddnstr(wp, l++, 20, inhost->hostname, COLS - 20);
     if (inhost->virt) {
-	mvwaddnstr(wp, l  ,  2, _("Machine Type:")        , COLS -  2);
-	mvwaddnstr(wp, l++, 20, inhost->virt           , COLS - 20);
+	mvwaddnstr(wp, l  ,  2, _("Machine Type:"), COLS -  2);
+	mvwaddnstr(wp, l++, 20, inhost->virt, COLS - 20);
     }
     if (inhost->uname_machine && inhost->uname_machine[0]) {
-	mvwaddnstr(wp, l  ,  2, _("Architecture:")        , COLS -  2);
-	mvwaddnstr(wp, l++, 20, inhost->uname_machine  , COLS - 20);
+	mvwaddnstr(wp, l  ,  2, _("Architecture:"), COLS -  2);
+	mvwaddnstr(wp, l++, 20, inhost->uname_machine, COLS - 20);
+    }
+    if (inhost->uuid[0]) {
+	mvwaddnstr(wp, l  ,  2, _("UUID:"), COLS -  2);
+	mvwaddnstr(wp, l++, 20, inhost->uuid, COLS - 20);
     }
     if (inhost->forbid & HOST_FORBID_MASK) {
 	mvwaddnstr(wp, l  , 2, _("Forbidden:"), COLS - 2);
 
 	strcpy(buf, " ");
 	if (inhost->forbid & HOST_FORBID_REFRESH) {
-	    strcat(buf, "refresh");
+	    strcat(buf, _("refresh"));
 	}
 
 	if (inhost->forbid & HOST_FORBID_UPGRADE) {
 	    if(strlen(buf) > 1) {
 		strcat(buf, ", ");
 	    }
-	    strcat(buf, "upgrade");
+	    strcat(buf, _("upgrade"));
 	}
 
 	if (inhost->forbid & HOST_FORBID_INSTALL) {
 	    if(strlen(buf) > 1) {
 		strcat(buf, ", ");
 	    }
-	    strcat(buf, "install");
+	    strcat(buf, _("install"));
 	}
 	mvwaddnstr(wp, l++, 15, buf        , COLS - 15);
     }
@@ -3291,22 +3324,22 @@ gboolean ctrlUI (GList *hosts)
     l++;
 
     if (inhost->lsb_distributor) {
-	mvwaddnstr(wp, l  ,  2, _("Distri:")              , COLS -  2);
+	mvwaddnstr(wp, l  ,  2, _("Distri:"), COLS -  2);
         mvwaddnstr(wp, l++, 20, inhost->lsb_distributor, COLS - 20);
         if (inhost->lsb_codename)
 	    snprintf(buf, sizeof(buf), "%s (%s)", inhost->lsb_release, inhost->lsb_codename);
 	else
 	    snprintf(buf, sizeof(buf), "%s", inhost->lsb_release);
-	mvwaddnstr(wp, l  ,  2, _("Release:")             , COLS -  2);
-        mvwaddnstr(wp, l++, 20, buf                    , COLS - 20);
+	mvwaddnstr(wp, l  ,  2, _("Release:"), COLS -  2);
+        mvwaddnstr(wp, l++, 20, buf, COLS - 20);
     }
     if (inhost->uname_kernel && inhost->uname_kernel[0]) {
-	mvwaddnstr(wp, l  ,  2, _("Kernel name:")         , COLS -  2);
-	mvwaddnstr(wp, l++, 20, inhost->uname_kernel   , COLS - 20);
+	mvwaddnstr(wp, l  ,  2, _("Kernel name:"), COLS -  2);
+	mvwaddnstr(wp, l++, 20, inhost->uname_kernel, COLS - 20);
     }
     if (inhost->kernelrel) {
-	mvwaddnstr(wp, l  ,  2, _("Kernel version:")      , COLS -  2);
-	mvwaddnstr(wp, l++, 20, inhost->kernelrel      , COLS - 20);
+	mvwaddnstr(wp, l  ,  2, _("Kernel version:"), COLS -  2);
+	mvwaddnstr(wp, l++, 20, inhost->kernelrel, COLS - 20);
 	
 	switch(inhost->status & (HOST_STATUS_KERNELNOTMATCH | HOST_STATUS_KERNELSELFBUILD)) {
 	    case HOST_STATUS_KERNELNOTMATCH:
@@ -3331,14 +3364,14 @@ gboolean ctrlUI (GList *hosts)
 	snprintf(buf, sizeof(buf), "%d installed (%d update%s, %d hold back, %d broken, %d extra)",
 		 g_list_length(inhost->packages), inhost->nupdates, inhost->nupdates == 1 ? "" : "s",
 		 inhost->nholds, inhost->nbrokens, inhost->nextras);
-	mvwaddnstr(wp, l++, 20, buf        , COLS - 20);
+	mvwaddnstr(wp, l++, 20, buf, COLS - 20);
     }
 
     if (inhost->nbrokens) {
 	l++;
 
 	wattron(wp, A_BOLD);
-	mvwaddnstr(wp, l++,  1, _("BROKEN PACKAGES")  , COLS - 1);
+	mvwaddnstr(wp, l++,  1, _("BROKEN PACKAGES"), COLS - 1);
 	wattroff(wp, A_BOLD);
 
 	GList *p = g_list_first(inhost->packages);
